//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

#define SLAVE_ADDRESS 0x50 

/* setup a 64 byte buffer */  
BYTE    txBuffer[34];  
BYTE    rxBuffer[32];  
BYTE    status;  

/* program counter */
unsigned short  sCounter;
/* receive data */
BYTE  bReceive;

/* ---------------------------------------------- */
/* --- I2C write                                  */
/* ---------------------------------------------- */
void write_i2c(unsigned short address, unsigned char length)
{
    /* Wait until the data is transferred */  
    while(!I2CHW_1_bReadI2CStatus() & I2CHW_WR_COMPLETE);  
    /* Clear Write Complete Status bit */  
    I2CHW_1_ClrWrStatus();  

	/* address */
	txBuffer[0] = (address >> 8) & 0xff;
	txBuffer[1] = (address & 0xff);
	/* --- I2C write */
	I2CHW_1_bWriteBytes(SLAVE_ADDRESS, txBuffer, length+2, I2CHW_1_CompleteXfer); 
}


/* ---------------------------------------------- */
/* --- read from rx8                              */
/* ---------------------------------------------- */
int read_rx8(void)
{
    BYTE bRxStatus;  

   	/* Wait to receive full byte*/  
   	while ( !( bRxStatus = RX8_1_bReadRxStatus() & RX8_RX_COMPLETE ) );
    /* data received, now check for errors */  
   	if (( bRxStatus & RX8_1_RX_NO_ERROR ) == 0 ) {  
        /* no error detected */  
   	    bReceive = RX8_1_bReadRxData();
   	    return(TRUE);  
    }
    else {
        /* error detected */  
        bReceive = bRxStatus;  
        return( FALSE );  
   	}
}



/* ---------------------------------------------- */
/* --- main routine                               */
/* ---------------------------------------------- */
void main()
{
	unsigned char  data;
	unsigned char  chunkCounter;
	char  i;

    /* --- initialize */
    LCD_1_Start();
    RX8_1_Start(RX8_PARITY_NONE);
	I2CHW_1_Start();
	I2CHW_1_EnableMstr();
	I2CHW_1_EnableInt();
	M8C_EnableGInt;
    
    LCD_1_Position(0, 0);
	
	sCounter = 0;
	chunkCounter = 0;
    /* --- loop */
    while(1) {
    	bReceive = RX8_1_cGetChar();
		rxBuffer[chunkCounter] = bReceive;
		chunkCounter++;
		if (chunkCounter == 32) {
			for(i=0; i<32; i++) {
				txBuffer[i+2] = rxBuffer[i];
			}
			/* I2C write */
			write_i2c(sCounter, 32);
			/* countinue */
			chunkCounter = 0;
			sCounter += 32;
		}
		/* - display */
	    LCD_1_Position(0, 0);
	    LCD_1_PrHexInt(sCounter);		
    }
}
